@@ -17,3 +17,9 @@
 		"msr	cpsr, %0" : "=r" (dummy) : : "memory");	\
 	} while(0)
 
+
+#define save_flags()						\
+	({ unsigned int __x; __asm__ __volatile__(		\
+		"mrs	%0, cpsr\n\t" : "=r" (__x));		\
+	   __x;							\
+	})
